@@ -26,10 +26,9 @@
 #'  (single value or vector of values)
 #' @param sky_condition a positive value (>=1) with which to scale
 #'  illuminance values (1 = cloud cover < 30%, 2 = thin veiled clouds
-#'  3 = average clouds, 10 = dark stratus clouds). By and large this
-#'  can be considered a scaling factor, substituting it with the (inverse)
-#'  slope parameter of an empirical fit should render more accurate results.
-#'  (this can be a single value or vector of values)
+#'  3 = average clouds, 10 = dark stratus clouds). The value is set 1 (one) by
+#'  default if missing (when all arguments are provided or should the column
+#'  not be present in a data frame).
 #'
 #' @return Sun and moon illuminance values (in lux), as well as their respective
 #' location in the sky (altitude, azimuth).
@@ -103,8 +102,6 @@ skylight <- function(
     # if not there
     if("sky_condition" %in% colnames(.data)){
       sky_condition <- .data$sky_condition
-    } else {
-      message("No sky condition provided, using the default value (1)!")
     }
   }
 
